﻿if((Get-PSSnapin -Name Microsoft.SharePoint.PowerShell -ErrorAction SilentlyContinue) -eq $null) {
    Add-PSSnapin Microsoft.SharePoint.PowerShell
} 

function Clear-IISandSPLogs([Int] $days, [String] $outputLog, [String] $logName)
{      
    New-Item -Path $outputLog -Name $logName -ItemType File -Force #overwrite log file by default
    
    #check if $outputLog directory contains "\" at the end of string
    if(($outputLog.Substring($outputLog.Length -1) -eq "\")) {
        $fullLogPath = $outputLog + $logName
    } else {
        $fullLogPath = $outputLog + "\" + $logName
    }
    
    # variables
    $keepLogsFor = $days
    $spInstalled = $true # flag if sharepoint is installed and logs should be cleared
    $spLogsPath = ""
    $IISlogsPath = "C:\inetpub\logs\LogFiles" 

    #check Sharepoint version and set flag
    $spFarm = Get-SPFarm
    $spVersion = $spFarm.BuildVersion.Major
    
    if($spVersion -eq 14) {
        $spLogsPath = "C:\Program Files\Common Files\Microsoft Shared\Web Server Extensions\14\LOGS"
    } elseif($spVersion -eq  15) {
        $spLogsPath = "C:\Program Files\Common Files\Microsoft Shared\Web Server Extensions\15\LOGS"
    } elseif($spVersion -eq 16){
        $spLogsPath = "C:\Program Files\Common Files\Microsoft Shared\Web Server Extensions\16\LOGS"
    } else {
        Write-Output "No version of SharePoint was found." | Out-File -Append $fullLogPath
        $spInstalled = $false
    }

    # removing IIS logs
    $IISlogsToDelete = ls $IISlogsPath -Recurse -File *.log | Where LastWriteTime -lt ((Get-Date).AddDays($keepLogsFor))

    if($IISlogsToDelete.Count -gt 0) {
    try {
        ForEach($file in $IISlogsToDelete) {
            "$($file.BaseName) is older than $((Get-Date).AddDays($keepLogsFor)) and will be deleted" | Out-File -Append $fullLogPath
            Get-Item $file.PSPath | Remove-Item -Verbose
            
        }
    } catch {
        $ErrorMessage = $_.Exception.Message
        $StackTrace = $_.Exception.StackTrace
        Write-Output "Trying to remove log files failed with following message:`n$ErrorMessage`n`nStacktrace:`n $StackTrace" | Out-File -Append $fullLogPath
    }

    } else {
        "No IIS logs to be deleted today $($(Get-Date).DateTime)" | Out-File -Append $fullLogPath
    }
    
    # removing SharePoint logs if $spInstalled flag set to true
    if($spInstalled -eq $true) {
        $spLogsToDelete = ls $spLogsPath -Recurse -File *.log | Where LastWriteTime -lt ((Get-Date).AddDays($keepLogsFor))

        if($spLogsToDelete.Count -gt 0) {
            try {
                ForEach($file in $spLogsToDelete) {
                    "$($file.BaseName) is older than $((Get-Date).AddDays($keepLogsFor)) will be deleted" | Out-File -Append $fullLogPath
                    Get-Item $file.PSPath | Remove-Item -Verbose # use $file.PSPath instead of just $file
                }
            } catch {
                $ErrorMessage = $_.Exception.Message
                $StackTrace = $_.Exception.StackTrace
                Write-Output "Trying to remove log files failed with following message:`n$ErrorMessage`n`nStacktrace:`n $StackTrace" | Out-File -Append $fullLogPath
            }
        } else {
            "No SharePoint logs to be deleted today $($(Get-Date).DateTime)" | Out-File -Append $fullLogPath
        }
    } else {
        Write-Output "Did not remove any logs. No version of SharePoint was found." | Out-File -Append $fullLogPath
    } 
    
    # finish script 
    Write-Output "Cleanup of log files older than $((Get-Date).AddDays($keepLogsFor)) finished correctly." | Out-File -Append $fullLogPath
}

Clear-IISandSPLogs $args[0] $args[1] $args[2]
